==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Submit_News/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_LANGUAGE","");
define("_PRINTER","˹͡Ѻͧ");
define("_FRIEND","ͧ͹ҹ");
define("_YOURNAME","ͤس");
define("_OK","ŧ!");
define("_ALLOWEDHTML"," HTML ö:");
define("_EXTRANS","Extrans (¹ html tags ѡø)");
define("_HTMLFORMATED","ѹ֡ HTML");
define("_PLAINTEXT","Ż");
define("_ARTICLES","");
define("_SUBMITNEWS","ͧͤ͢");
define("_SUBMITADVICE","ô¹ͧͺͧŧẺҧҧ Ǥԡ <br> سҵǨͺҡó С ١ͧ .<br> ҧҹʧǹԷԾԨó ЧѺ");
define("_SUBTITLE","ͧ");
define("_BEDESCRIPTIVE","ôк Ѵਹ  ЪѺ");
define("_BADTITLES","ͤͧ ='ôҹ.....'   'ͧ.....'");
define("_HTMLISFINE","ҹöá HTML  URLs link   سҵǨͺ١ͧ͹");
define("_AREYOUSURE","سҵǨͺ link URL .١ͧ");
define("_SUBPREVIEW","سҵǨټź͡͹͹");
define("_SELECTTOPIC","ô͡Ǣ");
define("_NEWSUBPREVIEW","ʴš͹");
define("_STORYLOOK","ͧͧسʴҾѧ:");
define("_CHECKSTORY","ôǨͺͤ link URL  HTML ͹ͧͧҹ !");
define("_THANKSSUB","ͺسѺͧ!");
define("_SUBSENT","ͧͧسѺº...");
define("_SUBTEXT","ҧҨзӡõǨͺͧ  仢ǢͷǢͧ.");
define("_WEHAVESUB","йͧҨӹǹ");
define("_WAITING","ͧ ͡");
define("_PREVIEW","ͧʴźҾ");
define("_NEWUSER","Ҫԡ");
define("_USCORE","Score");
define("_DATE","ѹ");
define("_STORYTEXT","Story Text");
define("_EXTENDEDTEXT","Extended Text");
define("_JANUARY","January");
define("_FEBRUARY","February");
define("_MARCH","March");
define("_APRIL","April");
define("_MAY","May");
define("_JUNE","June");
define("_JULY","July");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","October");
define("_NOVEMBER","November");
define("_DECEMBER","December");
define("_SELECTMONTH2VIEW","Please select the month you want to view:");
define("_SHOWALLSTORIES","Show ALL Stories");
define("_STORIESARCHIVE","Stories Archive");
define("_ACTIONS","Actions");
define("_ARCHIVESINDEX","Stories Archive Index");
define("_ALLSTORIESARCH","All Stories");
define("_NEXTPAGE","Next Page");
define("_PREVIOUSPAGE","Previous Page");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Submit_News/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_LANGUAGE","");
define("_PRINTER","˹͡Ѻͧ");
define("_FRIEND","ͧ͹ҹ");
define("_YOURNAME","ͤس");
define("_OK","ŧ!");
define("_ALLOWEDHTML"," HTML ö:");
define("_EXTRANS","Extrans (¹ html tags ѡø)");
define("_HTMLFORMATED","ѹ֡ HTML");
define("_PLAINTEXT","Ż");
define("_ARTICLES","");
define("_SUBMITNEWS","ͧͤ͢");
define("_SUBMITADVICE","ô¹ͧͺͧŧẺҧҧ Ǥԡ <br> سҵǨͺҡó С ١ͧ .<br> ҧҹʧǹԷԾԨó ЧѺ");
define("_SUBTITLE","ͧ");
define("_BEDESCRIPTIVE","ôк Ѵਹ  ЪѺ");
define("_BADTITLES","ͤͧ ='ôҹ.....'   'ͧ.....'");
define("_HTMLISFINE","ҹöá HTML  URLs link   سҵǨͺ١ͧ͹");
define("_AREYOUSURE","سҵǨͺ link URL .١ͧ");
define("_SUBPREVIEW","سҵǨټź͡͹͹");
define("_SELECTTOPIC","ô͡Ǣ");
define("_NEWSUBPREVIEW","ʴš͹");
define("_STORYLOOK","ͧͧسʴҾѧ:");
define("_CHECKSTORY","ôǨͺͤ link URL  HTML ͹ͧͧҹ !");
define("_THANKSSUB","ͺسѺͧ!");
define("_SUBSENT","ͧͧسѺº...");
define("_SUBTEXT","ҧҨзӡõǨͺͧ  仢ǢͷǢͧ.");
define("_WEHAVESUB","йͧҨӹǹ");
define("_WAITING","ͧ ͡");
define("_PREVIEW","ͧʴźҾ");
define("_NEWUSER","Ҫԡ");
define("_USCORE","Score");
define("_DATE","ѹ");
define("_STORYTEXT","Story Text");
define("_EXTENDEDTEXT","Extended Text");

define("_SELECTMONTH2VIEW","Please select the month you want to view:");
define("_SHOWALLSTORIES","Show ALL Stories");
define("_STORIESARCHIVE","Stories Archive");
define("_ACTIONS","Actions");
define("_ARCHIVESINDEX","Stories Archive Index");
define("_ALLSTORIESARCH","All Stories");
define("_NEXTPAGE","Next Page");
define("_PREVIOUSPAGE","Previous Page");

?>
